@@ -9,6 +9,7 @@ use Panda::Bundler;
 use Panda::Reporter;
 use Shell::Command;
 use JSON::Fast;
+use File::Which :whence;
 
 sub tmpdir {
     state $i = 0;
@@ -115,7 +116,36 @@ class Panda {
         }
     }
 
-    method install(Panda::Project $bone, $nodeps, $notests,
+    method !check-perl-version(Panda::Project $bone) {
+        if $bone.metainfo<perl> -> $perl-version-str is copy {
+            note "Please remove leading 'v' from perl version in {$bone.Str}'s meta info."
+                if $perl-version-str ~~ s/^v//; # remove superfluous leading "v"
+            my $perl-version = Version.new($perl-version-str);
+            use MONKEY-SEE-NO-EVAL;
+            my Bool $supported = try { EVAL "use { $perl-version.gist }"; True };
+            die "$bone requires Perl version $perl-version-str. Cannot continue."
+                unless $supported;
+        }
+    }
+    method uninstall(Panda::Project $bone is copy, :$prefix) {
+        my $bmeta = $bone.metainfo;
+        my $short-name = $bmeta<name>;
+        my $ver = $bmeta<ver> // $bmeta<version> //  '';
+        my $auth = $bmeta<auth> // $bmeta<author> // $bmeta<authority> // '';
+        my $api = $bmeta<api> // ''; 
+
+        my $comp-unit = $*REPO.resolve(CompUnit::DependencySpecification.new(:$short-name, :$ver, :$auth, :$api));
+
+        die "{$short-name} not installed" unless $comp-unit.defined;
+
+        $comp-unit.repo.uninstall($comp-unit.distribution);
+
+        my $s = Panda::Project::State::absent;
+        $.ecosystem.project-set-state($bone, $s);
+
+    }
+
+    method install(Panda::Project $bone is copy, $nodeps, $notests,
                    Bool() $isdep, :$rebuild = True, :$prefix, Bool :$force) {
         my $cwd = $*CWD;
         my $dir = tmpdir();
@@ -129,15 +159,28 @@ class Panda {
         unless $_ = $.fetcher.fetch($source, $dir) {
             die X::Panda.new($bone.name, 'fetch', $_)
         }
+        $bone.update-from-meta-file(find-meta-file(~$dir));
+
+        self!check-perl-version($bone);
         self.announce('building', $bone);
         unless $_ = $.builder.build($dir, :$bone) {
             die X::Panda.new($bone.name, 'build', $_)
         }
         unless $notests {
             self.announce('testing', $bone);
-            my %args = %*ENV<PROVE_COMMAND>
-                ??  prove-command => %*ENV<PROVE_COMMAND>
-                !! ();
+
+            my %args =();
+            if whence('prove6') {
+                if $*DISTRO.name eq 'mswin32' {
+                    %args = prove-command => 'prove6.bat';
+                }
+                else {
+                    %args = prove-command => 'prove6';
+                }
+            }
+
+            %args = prove-command => %*ENV<PROVE_COMMAND> if %*ENV<PROVE_COMMAND>;
+
             unless $_ = $.tester.test($dir, :$bone, |%args) {
                 die X::Panda.new($bone.name, 'test', $_, :$bone)
             }
@@ -201,8 +244,8 @@ class Panda {
         if not $bone {
             sub die($m) { X::Panda.new($proj, 'resolve', $m).throw }
             my $suggestion = $.ecosystem.suggest-project($proj);
-            die "Project $proj not found in the ecosystem. Maybe you meant $suggestion?" if $suggestion;
-            die "Project $proj not found in the ecosystem";
+            $suggestion = $suggestion ?? " Maybe you meant $suggestion?" !! '';
+            die qq[Project $proj not found in the ecosystem.$suggestion Maybe try "panda update" first?];
         }
 
         unless $nodeps {
@@ -218,6 +261,9 @@ class Panda {
             when 'install' {
                 self.install($bone, $nodeps, $notests, 0, :$prefix, :$force);
             }
+            when 'uninstall' {
+                self.uninstall($bone, :$prefix);
+            }
             when 'install-deps-only' { }
             when 'look'    { self.look($bone) };
         }
